function ffx_batch_job(t)

%-----------------------------------------------------------------------
% function to run ffx analyses for M&M2017 data set
%
% Author:   Sandra Iglesias
% Created:  2017-11-10
% Copyright (C) 2017 Institute for Biomedical Engineering
%                    University of Zurich and ETH Zurich
%-----------------------------------------------------------------------

addpath C:\Users\Sandra' Iglesias'\Documents\Documents\code\GitTNU\software\spm12\
% spm('defaults','FMRI')
% spm_jobman('initcfg');
dirScans = 'E:\Documents_E\Seminars\M&M_Mantelstudium2017\MandM\MethodsAndModels\2017\Data\Results0001\';
maskScans = 'Sub*';
maskfMRI = '\scandata';
maskGLM  = {'\glm\Level1_0001', '\glm\Level1_0002', '\glm\Level1_0003'};
maskVersion = {'Arrow', 'Button Press', 'Retinotopy'};

if t == 1
    maskContrast = {'Left vs Right Arrow: all', 'Right vs Left Arrow: all', ...
        'Left vs Right Arrow: block', 'Right vs Left Arrow: block', 'Left vs Right Arrow: event', 'Right vs Left Arrow: event'};
    dirGroup = ([dirScans,'\Group\FFX\Level_001_ffx']);
    regressorFile1 =  '\behav\LRArrowRegs01';
    regressorFile2 =  '\behav\LRArrowRegs02';
    mkdir(dirGroup);
elseif t ==2
    maskContrast = {'Left vs Right Press: all', 'Right vs Left Press: all', ...
        'Left vs Right Press: block', 'Right vs Left Press: block', 'Left vs Right Press: event', 'Right vs Left Press: event'};
    dirGroup = ([dirScans,'\Group\FFX\Level_002_ffx']);
    regressorFile1 =  '\behav\LRPressRegs01';
    regressorFile2 =  '\behav\LRPressRegs02';
else
    maskContrast = {'TLBR vs TRBL: all', 'TRBL vs TLBR: all', ...
        'TLBR vs TRBL: block', 'TRBL vs TLBR:  block', 'TLBR vs TRBL: event', 'TRBL vs TLBR: event'};
    dirGroup = ([dirScans,'\Group\FFX\Level_003_ffx']);
    regressorFile1 =  '\behav\WedgeRegs01';
    regressorFile2 =  '\behav\WedgeRegs02';
end
scans = dir(fullfile(dirScans,maskScans));
scans = {scans.name};
try, iScans; catch; iScans = 1:length(scans); end
disp(['ffx analysis: ', maskVersion{t},]);
disp(' ');
%-----------------------------------------------------------------------
% specify design matrix and contrasts
%-----------------------------------------------------------------------
matlabbatch{1}.spm.stats.fmri_spec.dir = {fullfile(dirGroup)};
matlabbatch{1}.spm.stats.fmri_spec.timing.units = 'secs';
matlabbatch{1}.spm.stats.fmri_spec.timing.RT = 2.2;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t = 32;
matlabbatch{1}.spm.stats.fmri_spec.timing.fmri_t0 = 16;

for i = 1:length(scans)
    [fp, fn, ext] = fileparts([dirScans,scans{i},'\scandata\swuafmri01.nii']);
    matlabbatch{1}.spm.stats.fmri_spec.sess(i).scans = cellstr(spm_select('ExtFPList', fp, ['^' fn ext], Inf));
    matlabbatch{1}.spm.stats.fmri_spec.sess(i).cond = struct('name', {}, 'onset', {}, 'duration', {}, 'tmod', {}, 'pmod', {}, 'orth', {});
    matlabbatch{1}.spm.stats.fmri_spec.sess(i).multi = {[dirScans,scans{i},regressorFile1,'.mat']};
    matlabbatch{1}.spm.stats.fmri_spec.sess(i).regress = struct('name', {}, 'val', {});
    matlabbatch{1}.spm.stats.fmri_spec.sess(i).multi_reg = {[dirScans,scans{i},maskfMRI,'\rp_afmri01.txt']};
    matlabbatch{1}.spm.stats.fmri_spec.sess(i).hpf = 128;
end

for i = 1:length(scans)
    [fp, fn, ext] = fileparts([dirScans,scans{i},'\scandata\swuafmri02.nii']);
    matlabbatch{1}.spm.stats.fmri_spec.sess(6+i).scans = cellstr(spm_select('ExtFPList', fp, ['^' fn ext], Inf));
    matlabbatch{1}.spm.stats.fmri_spec.sess(6+i).cond = struct('name', {}, 'onset', {}, 'duration', {}, 'tmod', {}, 'pmod', {}, 'orth', {});
    matlabbatch{1}.spm.stats.fmri_spec.sess(6+i).multi = {[dirScans,scans{i},regressorFile2,'.mat']};
    matlabbatch{1}.spm.stats.fmri_spec.sess(6+i).regress = struct('name', {}, 'val', {});
    matlabbatch{1}.spm.stats.fmri_spec.sess(6+i).multi_reg = {[dirScans,scans{i},maskfMRI,'\rp_afmri02.txt']};
    matlabbatch{1}.spm.stats.fmri_spec.sess(6+i).hpf = 128;
end
%%
matlabbatch{1}.spm.stats.fmri_spec.fact = struct('name', {}, 'levels', {});
matlabbatch{1}.spm.stats.fmri_spec.bases.hrf.derivs = [1 1];
matlabbatch{1}.spm.stats.fmri_spec.volt = 1;
matlabbatch{1}.spm.stats.fmri_spec.global = 'None';
matlabbatch{1}.spm.stats.fmri_spec.mthresh = 0.8;
matlabbatch{1}.spm.stats.fmri_spec.mask = {''};
matlabbatch{1}.spm.stats.fmri_spec.cvi = 'AR(1)';
matlabbatch{2}.spm.stats.fmri_est.spmmat(1) = cfg_dep('fMRI model specification: SPM.mat File', substruct('.','val', '{}',{1}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{2}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{2}.spm.stats.fmri_est.method.Classical = 1;
matlabbatch{3}.spm.stats.con.spmmat(1) = cfg_dep('Model estimation: SPM.mat File', substruct('.','val', '{}',{2}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{3}.spm.stats.con.consess{1}.tcon.name = maskContrast{1};
matlabbatch{3}.spm.stats.con.consess{1}.tcon.weights = [repmat([1 0 0 -1 0 0, zeros(1,6)],1,12)];
matlabbatch{3}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{2}.tcon.name = maskContrast{2};
matlabbatch{3}.spm.stats.con.consess{2}.tcon.weights = [repmat([-1 0 0 1 0 0, zeros(1,6)],1,12)];
matlabbatch{3}.spm.stats.con.consess{2}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{3}.tcon.name = maskContrast{3};
matlabbatch{3}.spm.stats.con.consess{3}.tcon.weights = [repmat([1 0 0 -1 0 0, zeros(1,6)],1,6)];
matlabbatch{3}.spm.stats.con.consess{3}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{4}.tcon.name = maskContrast{4};
matlabbatch{3}.spm.stats.con.consess{4}.tcon.weights = [repmat([-1 0 0 1 0 0, zeros(1,6)],1,6)];
matlabbatch{3}.spm.stats.con.consess{4}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{5}.tcon.name = maskContrast{5};
matlabbatch{3}.spm.stats.con.consess{5}.tcon.weights = [zeros(1,72), repmat([1 0 0 -1 0 0, zeros(1,6)],1,6)];
matlabbatch{3}.spm.stats.con.consess{5}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{6}.tcon.name = maskContrast{6};
matlabbatch{3}.spm.stats.con.consess{6}.tcon.weights = [zeros(1,72), repmat([-1 0 0 1 0 0, zeros(1,6)],1,6)];
matlabbatch{3}.spm.stats.con.consess{6}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.delete = 0;

spm_jobman('run',matlabbatch);
end


