function rfx_batch_job_Paired(t,d)

%-----------------------------------------------------------------------
% function to run rfx analyses for M&M2017 data set
%
% t = type of stimulus (arrow (1), press (2) or wedges (3))
% d = design (block (1) or event (2))
% Author:   Sandra Iglesias
% Created:  2017-11-10
% Copyright (C) 2017 Institute for Biomedical Engineering
%                    University of Zurich and ETH Zurich
%-----------------------------------------------------------------------

addpath C:\Users\Sandra' Iglesias'\Documents\Documents\code\GitTNU\software\spm12\
% spm('defaults','FMRI')
% spm_jobman('initcfg');
dirScans = 'E:\Documents_E\Seminars\M&M_Mantelstudium2017\MandM\MethodsAndModels\2017\Data\Results0001\';
maskScans = 'Sub*';
maskfMRI = '\scandata';
maskGLM  = {'\glm\Level1_0001', '\glm\Level1_0002', '\glm\Level1_0003'};
maskVersion = {'Arrow', 'Button Press', 'Retinotopy'};
maskConIndexBlock = {'\con_0011.nii', '\con_0012.nii'};
maskConIndexEvent = {'\con_0013.nii', '\con_0014.nii'};

if t == 1
    maskContrastBlock = {'Left vs Right Arrow: block', 'Right vs Left Arrow: block'};
    maskContrastEvent = {'Left vs Right Arrow: event', 'Right vs Left Arrow: event'};
    dirGroupBlock = ([dirScans,'\Group\Paired\Level_001_rfx\block']);
    dirGroupEvent = ([dirScans,'\Group\Paired\Level_001_rfx\event']);
    mkdir(dirGroupBlock);
    mkdir(dirGroupEvent);
elseif t ==2
    maskContrastBlock = {'Left vs Right Press: block', 'Right vs Left Press: block'};
    maskContrastEvent = {'Left vs Right Press: event', 'Right vs Left Press: event'};
    dirGroupBlock = ([dirScans,'\Group\Paired\Level_002_rfx\block']);
    dirGroupEvent = ([dirScans,'\Group\Paired\Level_002_rfx\event']);
    mkdir(dirGroupBlock);
    mkdir(dirGroupEvent);
else
    maskContrastBlock = {'TLBR vs TRBL: block', 'TRBL vs TLBR: block'};
    maskContrastEvent = {'TLBR vs TRBL: event', 'TRBL vs TLBR: event'};
    dirGroupBlock = ([dirScans,'\Group\Paired\Level_003_rfx\block']);
    dirGroupEvent = ([dirScans,'\Group\Paired\Level_003_rfx\event']);
    mkdir(dirGroupBlock);
    mkdir(dirGroupEvent);
end

scans = dir(fullfile(dirScans,maskScans));
scans = {scans.name};
try, iScans; catch; iScans = 1:length(scans); end
disp(['ffx analysis: ', maskVersion{t},]);
disp(' ');
%-----------------------------------------------------------------------
% specify design matrix and contrasts
%-----------------------------------------------------------------------
if d == 1
    matlabbatch{1}.spm.stats.factorial_design.dir = {fullfile(dirGroupBlock)};
    for i = 1:length(scans)
        matlabbatch{1}.spm.stats.factorial_design.des.pt.pair(i).scans = {
            [dirScans,scans{i},maskGLM{t},maskConIndexBlock{1},',1']
            [dirScans,scans{i},maskGLM{t},maskConIndexBlock{2},',1']
            };
    end
    matlabbatch{1}.spm.stats.factorial_design.des.pt.gmsca = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.pt.ancova = 0;
    matlabbatch{1}.spm.stats.factorial_design.cov = struct('c', {}, 'cname', {}, 'iCFI', {}, 'iCC', {});
    matlabbatch{1}.spm.stats.factorial_design.multi_cov = struct('files', {}, 'iCFI', {}, 'iCC', {});
    matlabbatch{1}.spm.stats.factorial_design.masking.tm.tm_none = 1;
    matlabbatch{1}.spm.stats.factorial_design.masking.im = 1;
    matlabbatch{1}.spm.stats.factorial_design.masking.em = {''};
    matlabbatch{1}.spm.stats.factorial_design.globalc.g_omit = 1;
    matlabbatch{1}.spm.stats.factorial_design.globalm.gmsca.gmsca_no = 1;
    matlabbatch{1}.spm.stats.factorial_design.globalm.glonorm = 1;
    matlabbatch{2}.spm.stats.fmri_est.spmmat(1) = cfg_dep('Factorial design specification: SPM.mat File', substruct('.','val', '{}',{1}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
    matlabbatch{2}.spm.stats.fmri_est.write_residuals = 0;
    matlabbatch{2}.spm.stats.fmri_est.method.Classical = 1;
    matlabbatch{3}.spm.stats.con.spmmat(1) = cfg_dep('Model estimation: SPM.mat File', substruct('.','val', '{}',{2}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
    matlabbatch{3}.spm.stats.con.consess{1}.tcon.name = maskContrastBlock{1};
    matlabbatch{3}.spm.stats.con.consess{1}.tcon.weights = [1 -1];
    matlabbatch{3}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
    matlabbatch{3}.spm.stats.con.consess{2}.tcon.name = maskContrastBlock{2};
    matlabbatch{3}.spm.stats.con.consess{2}.tcon.weights = [-1 1];
    matlabbatch{3}.spm.stats.con.consess{2}.tcon.sessrep = 'none';
    
else
    matlabbatch{1}.spm.stats.factorial_design.dir = {fullfile(dirGroupEvent)};
    for i = 1:length(scans)
        matlabbatch{1}.spm.stats.factorial_design.des.pt.pair(i).scans = {
            [dirScans,scans{i},maskGLM{t},maskConIndexEvent{1},',1']
            [dirScans,scans{i},maskGLM{t},maskConIndexEvent{2},',1']
            };
    end
    
    matlabbatch{1}.spm.stats.factorial_design.des.pt.gmsca = 0;
    matlabbatch{1}.spm.stats.factorial_design.des.pt.ancova = 0;
    matlabbatch{1}.spm.stats.factorial_design.cov = struct('c', {}, 'cname', {}, 'iCFI', {}, 'iCC', {});
    matlabbatch{1}.spm.stats.factorial_design.multi_cov = struct('files', {}, 'iCFI', {}, 'iCC', {});
    matlabbatch{1}.spm.stats.factorial_design.masking.tm.tm_none = 1;
    matlabbatch{1}.spm.stats.factorial_design.masking.im = 1;
    matlabbatch{1}.spm.stats.factorial_design.masking.em = {''};
    matlabbatch{1}.spm.stats.factorial_design.globalc.g_omit = 1;
    matlabbatch{1}.spm.stats.factorial_design.globalm.gmsca.gmsca_no = 1;
    matlabbatch{1}.spm.stats.factorial_design.globalm.glonorm = 1;
    matlabbatch{2}.spm.stats.fmri_est.spmmat(1) = cfg_dep('Factorial design specification: SPM.mat File', substruct('.','val', '{}',{1}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
    matlabbatch{2}.spm.stats.fmri_est.write_residuals = 0;
    matlabbatch{2}.spm.stats.fmri_est.method.Classical = 1;
    matlabbatch{3}.spm.stats.con.spmmat(1) = cfg_dep('Model estimation: SPM.mat File', substruct('.','val', '{}',{2}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
    matlabbatch{3}.spm.stats.con.consess{1}.tcon.name = maskContrastEvent{1};
    matlabbatch{3}.spm.stats.con.consess{1}.tcon.weights = [1 -1];
    matlabbatch{3}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
    matlabbatch{3}.spm.stats.con.consess{2}.tcon.name = maskContrastEvent{2};
    matlabbatch{3}.spm.stats.con.consess{2}.tcon.weights = [-1 1];
    matlabbatch{3}.spm.stats.con.consess{2}.tcon.sessrep = 'none';
    
end

spm_jobman('run',matlabbatch);
end


