function rfx_batch_job_wANOVA(t)

%-----------------------------------------------------------------------
% function to run rfx analyses for M&M2017 data set
%
% t = type of stimulus (arrow (1), press (2) or wedges (3))
% Author:   Sandra Iglesias
% Created:  2017-11-10
% Copyright (C) 2017 Institute for Biomedical Engineering
%                    University of Zurich and ETH Zurich
%-----------------------------------------------------------------------

addpath C:\Users\Sandra' Iglesias'\Documents\Documents\code\GitTNU\software\spm12\
% spm('defaults','FMRI')
% spm_jobman('initcfg');
dirScans = 'E:\Documents_E\Seminars\M&M_Mantelstudium2017\MandM\MethodsAndModels\2017\Data\Results0001\';
maskScans = 'Sub*';
maskfMRI = '\scandata';
maskGLM  = {'\glm\Level1_0001', '\glm\Level1_0002', '\glm\Level1_0003'};
maskVersion = {'Arrow', 'Button Press', 'Retinotopy'};
maskConIndex = {'\con_0011.nii', '\con_0012.nii', '\con_0013.nii', '\con_0014.nii'};


if t == 1
    maskContrast = {'Left vs Right Arrow: all', 'Right vs Left Arrow: all', ...
        'Left vs Right Arrow: block', 'Right vs Left Arrow: block', 'Left vs Right Arrow: event', 'Right vs Left Arrow: event'};
    dirGroup = ([dirScans,'\Group\wAnova\Level_001_rfx\']);
    mkdir(dirGroup);
elseif t ==2
    maskContrast = {'Left vs Right Press: all', 'Right vs Left Press: all', ...
        'Left vs Right Press: block', 'Right vs Left Press: block', 'Left vs Right Press: event', 'Right vs Left Press: event'};
    dirGroup = ([dirScans,'\Group\wAnova\Level_002_rfx\']);
    mkdir(dirGroup);
else
    maskContrast = {'TLBR vs TRBL: all', 'TRBL vs TLBR: all', ...
        'TLBR vs TRBL: block', 'TRBL vs TLBR:  block', 'TLBR vs TRBL: event', 'TRBL vs TLBR: event'};
    dirGroup = ([dirScans,'\Group\wAnova\Level_003_rfx\']);
    mkdir(dirGroup);
end

scans = dir(fullfile(dirScans,maskScans));
scans = {scans.name};
try, iScans; catch; iScans = 1:length(scans); end
disp(['ffx analysis: ', maskVersion{t},]);
disp(' ');
%-----------------------------------------------------------------------
% specify design matrix and contrasts
%-----------------------------------------------------------------------


matlabbatch{1}.spm.stats.factorial_design.dir = {fullfile(dirGroup)};
for i = 1:length(scans)
    matlabbatch{1}.spm.stats.factorial_design.des.anovaw.fsubject(i).scans = {
        [dirScans,scans{i},maskGLM{t},maskConIndex{1},',1']
        [dirScans,scans{i},maskGLM{t},maskConIndex{2},',1']
        [dirScans,scans{i},maskGLM{t},maskConIndex{3},',1']
        [dirScans,scans{i},maskGLM{t},maskConIndex{4},',1']};

matlabbatch{1}.spm.stats.factorial_design.des.anovaw.fsubject(i).conds = [1;2; 3;4];
end
matlabbatch{1}.spm.stats.factorial_design.des.anovaw.dept = 1;
matlabbatch{1}.spm.stats.factorial_design.des.anovaw.variance = 0;
matlabbatch{1}.spm.stats.factorial_design.des.anovaw.gmsca = 0;
matlabbatch{1}.spm.stats.factorial_design.des.anovaw.ancova = 0;
matlabbatch{1}.spm.stats.factorial_design.cov = struct('c', {}, 'cname', {}, 'iCFI', {}, 'iCC', {});
matlabbatch{1}.spm.stats.factorial_design.multi_cov = struct('files', {}, 'iCFI', {}, 'iCC', {});
matlabbatch{1}.spm.stats.factorial_design.masking.tm.tm_none = 1;
matlabbatch{1}.spm.stats.factorial_design.masking.im = 1;
matlabbatch{1}.spm.stats.factorial_design.masking.em = {''};
matlabbatch{1}.spm.stats.factorial_design.globalc.g_omit = 1;
matlabbatch{1}.spm.stats.factorial_design.globalm.gmsca.gmsca_no = 1;
matlabbatch{1}.spm.stats.factorial_design.globalm.glonorm = 1;
matlabbatch{2}.spm.stats.fmri_est.spmmat = cfg_dep('Factorial design specification: SPM.mat File', substruct('.','val', '{}',{1}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{2}.spm.stats.fmri_est.write_residuals = 0;
matlabbatch{2}.spm.stats.fmri_est.method.Classical = 1;
matlabbatch{3}.spm.stats.con.spmmat = cfg_dep('Model estimation: SPM.mat File', substruct('.','val', '{}',{2}, '.','val', '{}',{1}, '.','val', '{}',{1}), substruct('.','spmmat'));
matlabbatch{3}.spm.stats.con.consess{1}.tcon.name = maskContrast{1};
matlabbatch{3}.spm.stats.con.consess{1}.tcon.weights = [1 -1 1 -1];
matlabbatch{3}.spm.stats.con.consess{1}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{2}.tcon.name = maskContrast{2};
matlabbatch{3}.spm.stats.con.consess{2}.tcon.weights = [-1 1 -1 1];
matlabbatch{3}.spm.stats.con.consess{2}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{3}.tcon.name = maskContrast{3};
matlabbatch{3}.spm.stats.con.consess{3}.tcon.weights = [1 -1];
matlabbatch{3}.spm.stats.con.consess{3}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{4}.tcon.name = maskContrast{4};
matlabbatch{3}.spm.stats.con.consess{4}.tcon.weights = [-1 1];
matlabbatch{3}.spm.stats.con.consess{4}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{5}.tcon.name = maskContrast{5};
matlabbatch{3}.spm.stats.con.consess{5}.tcon.weights = [0 0 1 -1];
matlabbatch{3}.spm.stats.con.consess{5}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.consess{6}.tcon.name = maskContrast{6};
matlabbatch{3}.spm.stats.con.consess{6}.tcon.weights = [0 0 -1 1];
matlabbatch{3}.spm.stats.con.consess{6}.tcon.sessrep = 'none';
matlabbatch{3}.spm.stats.con.delete = 0;



spm_jobman('run',matlabbatch);
end


